--[[----------------------------------------------------------------------------
-- Duplex.MCU-Pro
----------------------------------------------------------------------------]]--

--[[

Inheritance: MCUPro > MidiDevice > Device

A specific class for devices that support the MCU-Pro protocol

--]]

--==============================================================================

class "MCUPro" (MidiDevice)

function MCUPro:__init(display_name, message_stream, port_in, port_out)
  TRACE("MCUPro:__init", display_name, message_stream, port_in, port_out)

  MidiDevice.__init(self, display_name, message_stream, port_in, port_out)

  self.allow_zero_velocity_note_on = true


end


--------------------------------------------------------------


function MCUPro:send_cc_message(number,value,channel)
  TRACE("MCUPro:send_cc_message()",number,value,channel)

  if (not self.midi_out or not self.midi_out.is_open) then
    return
  end

  if not channel then
    channel = self.default_midi_channel
  end

  -- ## NRPN
  if (duplex_preferences.nrpn_support.value == true) then
    -- hack to stop NRPN messages from being forwarded
    if (type(number) ~= "number") then 
      return 
    end
  end
  -- -- NRPN

  local message = {0xAF+channel, math.floor(number+32), math.floor(value)}

  local dump_str = ("MidiDevice: %s send MIDI %X %X %X"):format(
      self.port_out, message[1], message[2], message[3])

  if(self.dump_midi)then
    LOG(dump_str)
  else
    TRACE(dump_str)
  end


  self.midi_out:send(message)
end

--------------------------------------------------------------


